==> jc-1.4.0.tar.gz: javax/swing/Popup.h <==
// public class javax.swing.Popup

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 233bc5f46f80075e javax_swing_Popup

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_Popup_H_
#define _JC_javax_swing_Popup_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_Popup$sub_refs	_jc_javax_swing_Popup$sub_refs;
typedef struct _jc_javax_swing_Popup$sub_nonrefs	_jc_javax_swing_Popup$sub_nonrefs;
typedef struct _jc_javax_swing_Popup$refs	_jc_javax_swing_Popup$refs;
typedef struct _jc_javax_swing_Popup$nonrefs	_jc_javax_swing_Popup$nonrefs;
typedef struct _jc_javax_swing_Popup$object	_jc_javax_swing_Popup$object;

typedef const struct _jc_javax_swing_Popup$vmethods	_jc_javax_swing_Popup$vmethods;
typedef const struct _jc_javax_swing_Popup$vtable	_jc_javax_swing_Popup$vtable;
typedef const struct _jc_javax_swing_Popup$vtype	_jc_javax_swing_Popup$vtype;

// Constructors
extern void _jc_javax_swing_Popup$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_Popup$object *);
extern void _jc_javax_swing_Popup$method$_init$b51abd882b49de59(_jc_env *, struct _jc_javax_swing_Popup$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Component$object *, jint, jint);

// Virtual methods
extern void _jc_javax_swing_Popup$method$hide$048a3beb9ae7da95(_jc_env *, struct _jc_javax_swing_Popup$object *);
extern void _jc_javax_swing_Popup$method$show$8844e066fe447d0e(_jc_env *, struct _jc_javax_swing_Popup$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Popup$method_info$hide$048a3beb9ae7da95;
extern _jc_method _jc_javax_swing_Popup$method_info$show$8844e066fe447d0e;

// Virtual methods structure
struct _jc_javax_swing_Popup$vmethods {
	void	(*hide$048a3beb9ae7da95)(_jc_env *, struct _jc_javax_swing_Popup$object *);
	void	(*show$8844e066fe447d0e)(_jc_env *, struct _jc_javax_swing_Popup$object *);
};

// Vtable
struct _jc_javax_swing_Popup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_Popup$vmethods	javax_swing_Popup;
};

// Vtype
struct _jc_javax_swing_Popup$vtype {
	_jc_type			type;
	_jc_javax_swing_Popup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Popup$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_Popup$refs {
    _jc_javax_swing_Popup$sub_refs	javax_swing_Popup;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Popup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Popup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_Popup$sub_nonrefs	javax_swing_Popup;
};

// Object instance structure
struct _jc_javax_swing_Popup$object {
	_jc_javax_swing_Popup$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Popup$vtype	*vtype;
	_jc_javax_swing_Popup$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Popup$vtype _jc_javax_swing_Popup$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Popup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Popup$class_object;

#endif	/* _JC_javax_swing_Popup_H_ */

==> jc-1.4.6.tar.gz: javax/swing/Popup.h <==
// public class javax.swing.Popup

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 233bc5f46f80075e javax_swing_Popup

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_Popup_H_
#define _JC_javax_swing_Popup_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_Popup$sub_refs	_jc_javax_swing_Popup$sub_refs;
typedef struct _jc_javax_swing_Popup$sub_nonrefs	_jc_javax_swing_Popup$sub_nonrefs;
typedef struct _jc_javax_swing_Popup$refs	_jc_javax_swing_Popup$refs;
typedef struct _jc_javax_swing_Popup$nonrefs	_jc_javax_swing_Popup$nonrefs;
typedef struct _jc_javax_swing_Popup$object	_jc_javax_swing_Popup$object;

typedef const struct _jc_javax_swing_Popup$vmethods	_jc_javax_swing_Popup$vmethods;
typedef const struct _jc_javax_swing_Popup$vtable	_jc_javax_swing_Popup$vtable;
typedef const struct _jc_javax_swing_Popup$vtype	_jc_javax_swing_Popup$vtype;

// Constructors
extern void _jc_javax_swing_Popup$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_Popup$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_Popup$method$_init$b51abd882b49de59(_jc_env *, struct _jc_javax_swing_Popup$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Component$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_Popup$method$hide$048a3beb9ae7da95(_jc_env *, struct _jc_javax_swing_Popup$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_Popup$method$show$8844e066fe447d0e(_jc_env *, struct _jc_javax_swing_Popup$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Popup$method_info$hide$048a3beb9ae7da95;
extern _jc_method _jc_javax_swing_Popup$method_info$show$8844e066fe447d0e;

// Virtual methods structure
struct _jc_javax_swing_Popup$vmethods {
	void	(*hide$048a3beb9ae7da95)(_jc_env *, struct _jc_javax_swing_Popup$object *) _JC_JCNI_ATTR;
	void	(*show$8844e066fe447d0e)(_jc_env *, struct _jc_javax_swing_Popup$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_Popup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_Popup$vmethods	javax_swing_Popup;
};

// Vtype
struct _jc_javax_swing_Popup$vtype {
	_jc_type			type;
	_jc_javax_swing_Popup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Popup$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_Popup$refs {
    _jc_javax_swing_Popup$sub_refs	javax_swing_Popup;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Popup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Popup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_Popup$sub_nonrefs	javax_swing_Popup;
};

// Object instance structure
struct _jc_javax_swing_Popup$object {
	_jc_javax_swing_Popup$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Popup$vtype	*vtype;
	_jc_javax_swing_Popup$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Popup$vtype _jc_javax_swing_Popup$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Popup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Popup$class_object;

#endif	/* _JC_javax_swing_Popup_H_ */
